@@ -2,9 +2,9 @@
  * @Author: BuddyCoder
  * @Date: 2021-08-24 14:50:48
  * @LastEditors: BuddyCoder
- * @LastEditTime: 2022-03-29 18:07:46
+ * @LastEditTime: 2022-03-29 22:24:10
  * @Description: 
- * @FilePath: /pgmacro/src/macros/crud_table_impl.rs
+ * @FilePath: /pgmacro_expand_demo/pgmacro/src/macros/crud_table_impl.rs
  * MIT
  */
   //use proc_macro2::Ident;
@@ -142,7 +142,7 @@
 //  }
  fn py_get_name(table_name: &str) -> proc_macro2::TokenStream {
      quote! {
-         fn get_table_name(prefix: Option<&str>,suffix:Option<&str>) -> String {
+         fn get_table_name(prefix: Option<String>,suffix:Option<String>) -> String {
             let temp_table_name = match prefix {
                   Some(t) => format!("{}_{}",t,#table_name),
                   None => format!("{}",#table_name)
@@ -196,8 +196,8 @@
      //===========================================================================================================
      let py_insert_quoted = fields.iter().map(|f| f.py_insert_column());
      let py_insert = quote! {
-         fn save(&self,prefix:&str) -> Result<(String, Vec<&(dyn ToSql + Sync)>), String> {
-             let table_name = Self::get_table_name(prefix,"");
+         fn save(&self,prefix:Option<String>) -> Result<(String, Vec<&(dyn ToSql + Sync)>), String> {
+             let table_name = Self::get_table_name(prefix,None);
              let mut sql_columns: Vec<&str> = Vec::new();
              let mut sql_agrs: Vec<String> = Vec::new();
              let mut agrs: Vec<&(dyn ToSql + Sync)> = Vec::new();
@@ -224,7 +224,7 @@
      //=======================================================================================================
      let py_update_quoted = fields.iter().map(|f| f.py_update_column());
      let py_update = quote! {
-             fn update(&self,prefix:&str,suffix:&str) -> Result<(String, Vec<&(dyn ToSql + Sync)>, u32), String> {
+             fn update(&self,prefix:Option<String>,suffix:Option<String>) -> Result<(String, Vec<&(dyn ToSql + Sync)>, u32), String> {
                  let table_name = Self::get_table_name(prefix,suffix);
                  let mut sql_columns: Vec<String> = Vec::new();
                  // let mut sql_agrs: Vec<String> = Vec::new();
